<?php

namespace v1\controllers;

use common\data\Respuesta;
use common\rest\AuthController;
use yii\db\Expression;

class ServicioController extends AuthController {

  public $modelClass = "v1\models\Servicio";

  public function actionIndex() {
    $id = trim($this->req->get("id", ""));
    $buscar = trim($this->req->get("q", ""));
    $taller = trim($this->req->get("taller", ""));
    $vehiculo = trim($this->req->get("vehiculo", ""));
    
    $query = $this->queryInicial;
    

    if($id !== "") {
      $query->andWhere(["id" => $id]);
    }

    if($taller !== "") {
        $query->andWhere(["taller.id" => $taller]);
    }

    if($vehiculo !== "") {
        $query->andWhere(["vehiculo.id" => $vehiculo]);
    }

    if($buscar) {
      
      $query->andWhere([
        "OR",
        ["ilike", "nombre", $buscar]
      ]);

    }

    return new Respuesta($query, $this->limite, $this->pagina, $this->ordenar);
  }

  public function actionGuardar() {
    $id = trim($this->req->getBodyParam("id", ""));
    $modelo = null;

    if($id !== "") {
      $modelo = $this->modelClass::findOne($id);
    }
    if($modelo === null) {
      $modelo = new $this->modelClass();
      $modelo->uuid();
      $modelo->creado = new Expression('now()');
    } else {
      $modelo->modificado = new Expression('now()');
    }

    $modelo->load($this->req->getBodyParams(), '');
    if (!$modelo->save()) {
      return (new Respuesta($modelo))
        ->mensaje("Hubo un problema al guardar el Servicio");
    }

    $modelo->refresh();
    return (new Respuesta($modelo))
      ->mensaje("Serivicio guardado");
  }

  public function actionEliminar() {
    $id = trim($this->req->getBodyParam("id", ""));
    $modelo = null;

    if($id !== "") {
      $modelo = $this->modelClass::findOne(["id" => $id]);
    }
    if($modelo === null) {
      return (new Respuesta())
        ->esError()
        ->mensaje("Servicio no encontrado");
    }
    $modelo->eliminado = new Expression('now()');
    if(!$modelo->save()) {
      return (new Respuesta($modelo))
        ->mensaje("No se pudo eliminar Servicio");
    }

    return (new Respuesta())
      ->mensaje("Servicio eliminada");
  }
}